@@ -8,8 +8,8 @@
 ;; URL: https://codeberg.org/ideasman42/emacs-shift-number
 ;; Keywords: convenience
 ;; Created: 12 Apr 2016
-;; Package-Version: 20250917.433
-;; Package-Revision: 058fa3072932
+;; Package-Version: 20251126.348
+;; Package-Revision: bb14d9609fed
 ;; Package-Requires: ((emacs "24.1"))
 
 ;;; Commentary:
@@ -142,7 +142,7 @@ Return the region replaced."
     (let ((found nil)
           (exit nil))
       (goto-char limit-beg)
-      (while (and (not (or exit found)) (re-search-forward regexp limit-end t))
+      (while (and (null (or exit found)) (re-search-forward regexp limit-end t))
         (cond
          ((> (match-beginning 0) pos)
           (setq exit t))
